@@ -51,6 +51,8 @@ mr_radialegger_rjags <- function(object,
                                  seed = NULL,
                                  rho = 0.5,
                                  ...) {
+  # check if rjags is installed
+  rjags_check()
 
   # convert MRInput object to mr_format
   if ("MRInput" %in% class(object)) {
